@@ -1,4 +1,5 @@
-VERSION = (0, 9, 1, 'rc', 0)
+VERSION = (0, 10, 0, 'rc', 0)
+
 
 def get_version(version=None, include_sub=True):
     """Derives a PEP386-compliant version number from VERSION."""
@@ -26,7 +27,7 @@ def get_version(version=None, include_sub=True):
     elif version[3] != 'final':
         mapping = {'alpha': 'a', 'beta': 'b', 'rc': 'c'}
         sub = mapping[version[3]] + str(version[4])
-    
+
     if include_sub:
         return main + sub
     else:
@@ -57,3 +58,15 @@ def autodiscover():
             # attempting to import it, otherwise we want it to bubble up.
             if module_has_submodule(mod, 'resources'):
                 raise
+
+def get_api(namespace):
+    '''
+    Returns the root endpoint matching the namespace
+    '''
+    from django.core.urlresolvers import get_resolver, get_urlconf
+    #there should be a better way to do this...
+    urlconf = get_urlconf()
+    resolver = get_resolver(urlconf)
+    result = resolver.namespace_dict[namespace]
+    return result[1].urlconf_name
+
