@@ -1,25 +1,15 @@
-from django.utils.functional import Promise
-try:
-    from django.utils.encoding import force_text
-except ImportError:
-    from django.utils.encoding import force_unicode as force_text
-from django.core.serializers.json import DjangoJSONEncoder
 from django.utils import simplejson as json
 from django import http
 
+from hyperadmin.mediatypes.encoders import HyperadminJSONEncoder, force_text
 from hyperadmin.mediatypes.common import MediaType
 from hyperadmin.links import Link
 
 
-class LazyEncoder(DjangoJSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, Promise):
-            return force_text(obj)
-        return super(LazyEncoder, self).default(obj)
-
 class CollectionJSON(MediaType):
     recognized_media_types = [
-        'application/vnd.Collection+JSON'
+        'application/vnd.Collection+JSON',
+        'application/vnd.collection+json',
     ]
     
     def prepare_field_value(self, val):
@@ -111,9 +101,9 @@ class CollectionJSON(MediaType):
     
     def serialize(self, content_type, link, state):
         if self.detect_redirect(link):
-            return self.handle_redirect(link)
+            return self.handle_redirect(link, content_type)
         data = self.prepare_collection(link, state)
-        content = json.dumps({"collection":data}, cls=LazyEncoder)
+        content = json.dumps({"collection":data}, cls=HyperadminJSONEncoder)
         assert content_type in self.recognized_media_types, "%s not in %s" % (content_type, self.recognized_media_types)
         return http.HttpResponse(content, content_type)
     
@@ -121,7 +111,7 @@ class CollectionJSON(MediaType):
         methods = dict()
         for method, link in links.iteritems():
             methods[method] = {'collection':self.prepare_link(link)}
-        content = json.dumps(methods, cls=LazyEncoder)
+        content = json.dumps(methods, cls=HyperadminJSONEncoder)
         allow = ','.join(links.iterkeys())
         response = http.HttpResponse(content, content_type)
         response['Allow'] = allow
@@ -133,13 +123,16 @@ class CollectionJSON(MediaType):
             payload = request.body
         else:
             payload = request.raw_post_data
+        if not payload:
+            return {}
         data = json.loads(payload)
         data = data['data']
         form_data = dict()
         files = dict()
         for field in data:
+            f_type = field.get('type', 'text')
             form_data[field['name']] = field['value']
-            if field['type'] == 'file' and field['value']:
+            if f_type == 'file' and field['value']:
                 #TODO storage lookup could be done better
                 storage = self.site.applications['-storages'].resource_adaptor['media'].resource_adaptor
                 files[field['name']] = storage.open(field['value'])
