@@ -10,13 +10,13 @@ class PassthroughResponse(HttpResponse):
         super(PassthroughResponse, self).__init__(*args, **kwargs)
 
 class Passthrough(MediaType):
-    def handle_redirect(self, link):
+    def handle_redirect(self, link, content_type):
         if self.api_request.method != 'GET':
-            response = PassthroughResponse(link.get_absolute_url(), status=303)
-            response['Location'] = link.get_absolute_url()
+            status = 303
         else:
-            response = PassthroughResponse(link.get_absolute_url(), status=302)
-            response['Location'] = link.get_absolute_url()
+            status = 302
+        response = PassthroughResponse(link.get_absolute_url(), status=status, content_type=content_type)
+        response['Location'] = link.get_absolute_url()
         return response
     
     def detect_redirect(self, link):
@@ -28,7 +28,7 @@ class Passthrough(MediaType):
     
     def serialize(self, content_type, link, state):
         if self.detect_redirect(link):
-            return self.handle_redirect(link)
+            return self.handle_redirect(link, content_type)
         return PassthroughResponse('Unavailable (passthrough media type)', content_type, link=link, state=state)
     
     def deserialize(self):
