@@ -103,26 +103,27 @@ class BaseModelResource(CRUDResource):
         return indexes
     
     def lookup_allowed(self, lookup, value):
+        '''Currently unused'''
         return True #TODO
     
     def get_queryset(self):
         queryset = self.resource_adaptor.objects.all()
-        if not self.has_change_permission():
+        if not self.has_update_permission(): #TODO has_list_permission?
             queryset = queryset.none()
         return queryset
     
-    def has_add_permission(self):
+    def has_create_permission(self):
         user = self.api_request.user
         if self.opts.auto_created:
             # We're checking the rights to an auto-created intermediate model,
             # which doesn't have its own individual permissions. The user needs
             # to have the change permission for the related model in order to
             # be able to do anything with the intermediate model.
-            return self.has_change_permission()
+            return self.has_update_permission()
         return user.has_perm(
             self.opts.app_label + '.' + self.opts.get_add_permission())
 
-    def has_change_permission(self, item=None):
+    def has_update_permission(self, item=None):
         user = self.api_request.user
         
         if item:
@@ -148,7 +149,7 @@ class BaseModelResource(CRUDResource):
             # which doesn't have its own individual permissions. The user needs
             # to have the change permission for the related model in order to
             # be able to do anything with the intermediate model.
-            return self.has_change_permission(item)
+            return self.has_update_permission(item)
         return user.has_perm(
             self.opts.app_label + '.' + self.opts.get_delete_permission())
         
@@ -165,12 +166,27 @@ class BaseModelResource(CRUDResource):
                 #TODO formfield overides
                 #TODO fields
         return AdminForm
+    
+    def get_native_datatap_instream_from_items(self, items):
+        '''
+        Makes an instream of model instances
+        '''
+        return [item.instance for item in items]
+    
+    def get_native_datatap(self, instream=None, **kwargs):
+        '''
+        Returns a ModelDataTap suited for this resource
+        '''
+        from datatap.datataps import ModelDataTap
+        if instream is None:
+            instream = [self.resource_adaptor]
+        return ModelDataTap(instream, **kwargs)
 
 class ModelResource(BaseModelResource):
-    list_endpoint_class = ListEndpoint
-    create_endpoint_class = CreateEndpoint
-    detail_endpoint_class = DetailEndpoint
-    delete_endpoint_class = DeleteEndpoint
+    list_endpoint = (ListEndpoint, {'index_name':'filter'})
+    create_endpoint = (CreateEndpoint, {})
+    detail_endpoint = (DetailEndpoint, {})
+    delete_endpoint = (DeleteEndpoint, {})
     
     def post_register(self):
         super(ModelResource, self).post_register()
@@ -188,13 +204,6 @@ class ModelResource(BaseModelResource):
     def register_inline(self, inline_cls):
         self.inline_instances.append(inline_cls(parent=self, api_request=self.api_request))
     
-    def register_endpoint(self, endpoint_cls, **kwargs):
-        #TODO find a better strategy for injecting the index name for list endpoints
-        #perhaps list_endpoint could be a tuple of class and kwargs
-        if endpoint_cls == self.list_endpoint_class:
-            kwargs.setdefault('index_name', 'filter')
-        return super(ModelResource, self).register_endpoint(endpoint_cls, **kwargs)
-    
     def get_urls(self):
         urlpatterns = super(ModelResource, self).get_urls()
         for inline in self.inline_instances:
@@ -223,10 +232,10 @@ class InlineModelResource(BaseModelResource):
     fk_name = None
     rel_name = None
     
-    list_endpoint_class = InlineListEndpoint
-    create_endpoint_class = InlineCreateEndpoint
-    detail_endpoint_class = InlineDetailEndpoint
-    delete_endpoint_class = InlineDeleteEndpoint
+    list_endpoint = (InlineListEndpoint, {})
+    create_endpoint = (InlineCreateEndpoint, {})
+    detail_endpoint = (InlineDetailEndpoint, {})
+    delete_endpoint = (InlineDeleteEndpoint, {})
     
     def __init__(self, parent, **kwargs):
         kwargs['site'] = parent.site
@@ -246,7 +255,7 @@ class InlineModelResource(BaseModelResource):
     def get_queryset(self, parent):
         queryset = self.resource_adaptor.objects.all()
         queryset = queryset.filter(**{self.fk.name:parent})
-        if not self.has_change_permission():
+        if not self.has_update_permission():
             queryset = queryset.none()
         return queryset
     
